import { Button, Col, Drawer, Row } from "antd";
import React, { useState, useImperativeHandle, forwardRef, useRef } from "react";
import PageList from "./pageList";
import Content from "./content";
import SetData from "./set";
import { useToken } from "@ant-design/pro-components";
import { useSize } from "ahooks";
// 定义组件的 Props 类型
interface Props {
}

// 使用 forwardRef 以支持传递 ref
const ModalForm = forwardRef((props: Props, ref) => {
    const [open, setOpen] = useState(false);
    const headerSize = useSize(document.querySelector('.ant-drawer-header'));
    const { token } = useToken()
    const PageListRef = useRef<any>(null);
    const ContentRef = useRef<any>(null);
    const SetDataRef = useRef<any>(null);
    // close 方法，用于关闭 Drawer
    const close = () => {
        setOpen(false); // 将 open 设置为 false，关闭 Drawer
    };

    const openDrawer = () => {
        setOpen(true); // 将 open 设置为 true，打开 Drawer
    };

    // 使用 useImperativeHandle 暴露方法给父组件
    useImperativeHandle(ref, () => ({
        close,        // 暴露 close 方法
        openDrawer,   // 也可以暴露打开的方法
    }));
    return (
        <Drawer
            title="新建配置"
            placement="right"
            open={open}
            onClose={close}
            width={'85vw'}
            extra={<Button type='primary'>保存配置</Button>}
            maskClosable={false}
        >
            <Row wrap style={{height:`calc(100vh - ${(headerSize?.height || 0) + 50}px)`}}>
                {/* 左侧页面列表 pageList*/}
                <Col  xl={5} xs={24}>
                    <PageList ref={PageListRef}/>
                </Col>
                {/* 中间展示 content*/}
                <Col xl={14}  xs={24} style={{ background: token.colorBgContainerDisabled,display:'flex',alignItems:'center',justifyContent:'center' }}>
                    <Content ref={ContentRef}/>
                </Col>
                {/* 右侧参数设置 set*/}
                <Col xl={5} xs={24}>
                    <SetData ref={SetDataRef}/>
                </Col>
            </Row>
        </Drawer>
    );
});

export default ModalForm;