import { useDrag } from "ahooks";
import { Col, Row, Space, Typography } from "antd";
import React, { useState, useImperativeHandle, forwardRef, useRef } from "react";
import styles from './index.less'
const DragItem = ({ children }: any) => {
    const dragRef = useRef(null);
    const [dragging, setDragging] = useState(false);

    useDrag(children.key, dragRef, {
        onDragStart: () => {
            console.log(children.key)
            setDragging(true);
        },
        onDragEnd: () => {
            setDragging(false);
        },
    });

    return (
        <div
            ref={dragRef}
            style={{display:'inline-block'}}
        >
            {children}
        </div>
    );
};
// 定义组件的 Props 类型
interface Props {
}
// 使用 forwardRef 以支持传递 ref
const PageList = forwardRef((props: Props, ref) => {

    // 使用 useImperativeHandle 暴露方法给父组件
    useImperativeHandle(ref, () => ({
    }));

    return <Row gutter={[20, 20]} className={styles.pageList}>
        <Col span={24}>
            <Typography.Title level={4} >顶部组件</Typography.Title>
            <DragItem ><div key="banners" className={styles.banners}>banners</div></DragItem>
        </Col>
        <Col span={24}>
            <Typography.Title level={4} >内容组件</Typography.Title>
            <Space>
                <DragItem ><div key="hot_books">热门书籍</div></DragItem>
                <DragItem ><div key="hot_category">热门分类</div></DragItem>
            </Space>
        </Col>
    </Row>
});

export default PageList;